@@ -95,7 +95,8 @@ pub fn remove_nodes(collection_name: String, labels: Vec<String>) -> PyResult<u8
 #[pyfunction]
 pub fn update_node(collection_name: String, label: String, node: Bound<PyAny>) -> PyResult<bool> {
     let new_node: Value = from_pyobject(node)?;
-    rusted_graphs::update_node(collection_name, label, new_node).map_err(|e| PyValueError::new_err(e))
+    rusted_graphs::update_node(collection_name, label, new_node)
+        .map_err(|e| PyValueError::new_err(e))
 }
 
 #[gen_stub_pyfunction]
@@ -119,6 +120,32 @@ pub fn query_node(py: Python<'_>, collection_name: String, query: String) -> PyR
     // Ok(py_list.into_py(py))
 }
 
+#[gen_stub_pyfunction]
+#[pyfunction]
+pub fn add_edges(collection_name: String, edges: &Bound<'_, PyList>) -> PyResult<u8> {
+    let mut vals: Vec<Value> = Vec::with_capacity(edges.len());
+    for edge in edges.iter() {
+        let n: Value = from_pyobject(edge)?;
+        vals.push(n);
+    }
+
+    rusted_graphs::add_edges(collection_name, vals).map_err(|e| PyValueError::new_err(e))
+}
+
+#[gen_stub_pyfunction]
+#[pyfunction]
+pub fn add_edges_from_file(collection_name: String, json_path: String) -> PyResult<u8> {
+    rusted_graphs::add_edges_from_file(collection_name, json_path)
+        .map_err(|e| PyValueError::new_err(e))
+}
+
+#[gen_stub_pyfunction]
+#[pyfunction]
+pub fn remove_edge(collection_name: String, from_label: String, to_label: String) -> PyResult<u8> {
+    rusted_graphs::remove_edge(collection_name, from_label, to_label)
+        .map_err(|e| PyValueError::new_err(e))
+}
+
 define_stub_info_gatherer!(stub_info);
 
 #[pymodule]
@@ -134,5 +161,8 @@ fn rusted_graphs_python(_py: Python, m: &Bound<PyModule>) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(remove_nodes, m)?)?;
     m.add_function(wrap_pyfunction!(update_node, m)?)?;
     m.add_function(wrap_pyfunction!(query_node, m)?)?;
+    m.add_function(wrap_pyfunction!(add_edges, m)?)?;
+    m.add_function(wrap_pyfunction!(add_edges_from_file, m)?)?;
+    m.add_function(wrap_pyfunction!(remove_edge, m)?)?;
     Ok(())
 }
